/*
 * Sicherheitsunterweisung
 * Copyright (C) 2023  Jason Streifling
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package data

import "database/sql"

type DB struct {
	*sql.DB
}

type Person struct {
	ID        int64
	FirstName string
	LastName  string
}

type Instructor Person

type Participant struct {
	Person
	Company string
}

type Briefing struct {
	ID           int64
	DateTime     string
	Location     string
	Document     string
	AsOf         string
	InstructorID int64
}

type Answer struct {
	ID      int64
	Text    string
	IsImage bool // TODO: relocate to sessionStructs if possible
}

type Question struct {
	ID      int64
	Text    string
	Answers []Answer
	Correct int
}

type GivenAnswer struct {
	BriefingID    int64
	ParticipantID int64
	QuestionID    int64
	GivenAnswer   int
}

type OverviewTableData struct {
	InstructorFirstName  string
	InstructorLastName   string
	BriefingDateTime     string
	BriefingLocation     string
	BriefingDocument     string
	BriefingAsOf         string
	ParticipantFirstName string
	ParticipantLastName  string
	ParticipantCompany   string
}
